#	
#	Pymol Script for Endonuclease BAMHI
#	Michelle Womack-Davis, Graduate Student
#	Loren Williams, Georgia Tech
#

# delete all objects and reset pymol
reinitialize

# set the background color to white
bg_color white

# make the background transparent for #ray trace 
set ray_opaque_background, 0

# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2

# turn off shadows
set ray_shadows, 0

# set the mouse mode for laptop.
config_mouse one_button

# run the python program for hydrogen bonding interactions.
run files/python/list_hbonds.py
#------ put the python program list_hbonds.py
#------into the directory python.


load files/2BAM.pdb, 2BAM 

create Cartoon_DNA, 2BAM and chain C+D
hide everything, Cartoon_DNA
show cartoon, Cartoon_DNA
set cartoon_ring_mode=3, Cartoon_DNA
set cartoon_tube_radius=0.6, Cartoon_DNA
show cartoon, Cartoon_DNA

#----------------------Cartoon BAM---------------------

create Cartoon_BAM, 2BAM and chain A+B
color cyan, chain A
color cyan, chain B
set cartoon_cylindrical_helices,2, Cartoon_BAM
color blue, ss h and Cartoon_BAM
color magenta, ss s and Cartoon_BAM
hide everything, Cartoon_BAM
show cartoon, Cartoon_BAM

#----------------------Stick_DNA---------------------------

create Stick_DNA, 2BAM and chain C+D
remove resn HOH and Stick_DNA
hide everything, Stick_DNA
show stick, Stick_DNA

#--------------- Watson-Crick hydrogen bonds----------------

distance WC_Hbond, (name O2,N3,N4 and resn DC and Stick_DNA ), (name N2,N1,O6 and resn DG and Stick_DNA ), 3.2
distance WC_Hbond, (name N3,O4 and resn DT and Stick_DNA ), (name N1,N6 and resn DA and Stick_DNA ), 3.2
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.3
color black, WC_Hbond

#----------------Stick BAM----------------------

create Stick_BAM, 2BAM and chain A+B
hide everything, Stick_BAM
show stick, Stick_BAM
color limegreen, name C* and Stick_BAM
color blue, name N* and Stick_BAM
color red, name O* and Stick_BAM
color yellow, name S* and Stick_BAM


#--------------------------- Active Site------------------------------

create Active_Site, (resi 77,94,111-113 and chain A)
hide everything, Active_Site
Show Stick, 
Zoom Active_Site
color yellow, name C* and Active_Site
color red, name O* and Active_Site
color blue, name N* and Active_Site


create Calcium, resn CA
show sphere, Calcium
alter Calcium, vdw=.6 
rebuild
label Calcium, "CA"

distance CA_Coord,  (Calcium and name CA and resi 502), /Active_Site//A/GLU' 77/OE1, 3.2
distance CA_Coord,  (Calcium and name CA and resi 502), /Active_Site//A/ASP' 94/OD1, 3.2
distance CA_Coord,  (Calcium and name CA and resi 501), /Active_Site//A/ASP' 94/OD2, 3.2
distance CA_Coord,  (Calcium and name CA and resi 501), /Active_Site//A/GLU' 111/OE2, 3.2
distance CA_Coord,  (Calcium and name CA and resi 501), /Active_Site//A/PHE' 112/O, 3.2

distance CA_Coord,  (Calcium and name CA and (resi 501 or resi 502)), stick_DNA, 2.7

show dashes, CA_Coord
color black, CA_Coord




#------------------BAM-DNA Hydrogen Bonds-------------------------

show stick, Active_Site
distance H_Bond_Active_Site, (Active_Site and Chain C+D and name O*,N*), (Active_Site and Chain A+B and name O*,N* ), 3.4
color black, H_Bond_DNA_BAM


#----------------------ARM 194-203-----------------------------------

create ARM_194_203, (resi 194, 195, 196, 197, 198, 199, 200, 201, 202, 203 and chain B)
color white, ARM_194_203
color red, name O* and ARM_194_203
color blue, name N* and ARM_194_203
distance HBond_DNA_ARM, (Stick_DNA and Chain C+D and name O*,N*), (ARM_194_203 and Chain A+B and name O*,N* ), 3.4
color black, HBond_DNA_ARM
hide everything, ARM_194_203
show surface, ARM_194_203
set transparency, 0.5

create L_Arm_KWYYER, (resi 201, 206, 207, 75,69,96 and chain A)
distance HBond_DNA_ARM, (Stick_DNA and Chain C+D and name O*,N*), (L_Arm_KWYYER and Chain A+B and name O*,N* ), 3.4
color black, HBond_DNA_ARM
show surface, ARM_194_203
hide everything, L_Arm_KWYYER
show surface, L_ARM_KWYYER
set transparency, 0.5


#------------------------Conformational Change-----------------

create Mut_Glyc194_R, resi 194 and chain A
create Mut_Glyc194_L, resi 194 and chain B
show stick, Mut_Glyc194_L and Mut_Glyc194_R
distance Mut_Gly_Conf_LR,  /Mut_Glyc194_R//A/GLY`194/N, /Mut_Glyc194_L//B/GLY`194/N
color black, Mut_Gly_Conf_LR,  /Mut_Glyc194_R//A/GLY`194/N, /Mut_Glyc194_L//B/GLY`194/N 

create Mut_Arg_155, resi 155 and chain A
create Mut_IsoLeu_117, resi 117 and chain A
distance HBond_Mut_Arg_Ile, /Mut_Arg_155//A/ARG`155/O*, /Mut_IsoLeu_117//A/ILE`117/N, 3.4
color black, HBond_Mut_Arg_Ile, /Mut_Arg_155//A/ARG`155/O*, /Mut_IsoLeu_117//A/ILE`117/N


disable all
enable Cartoon_DNA
enable Cartoon_BAM



set_view (\
    -0.904402912,    0.351330042,    0.242098138,\
    -0.238731250,    0.053587981,   -0.969594359,\
    -0.353623241,   -0.934707642,    0.035412326,\
     0.000000000,    0.000000000, -180.007507324,\
    50.910457611,   32.623088837,   25.787309647,\
   136.397750854,  223.617263794,  -20.000000000 )

ray
#ray 900,900
